@@ -31,6 +31,7 @@ class ConfigInfoAppBase(object):
     def __init__(self, siteId=None, verbose=True, log=sys.stderr):
         self._cI = ConfigInfo(siteId=siteId, verbose=verbose, log=log)
         self._resourcedir = None
+        self._rwresourcedir = None
         self._referencedir = None
         self._site_archive_dir = None
         self._site_local_apps_path = None
@@ -58,6 +59,12 @@ class ConfigInfoAppBase(object):
             self._resourcedir = self._cI.get("RO_RESOURCE_PATH")
         return self._resourcedir
 
+    def _getrwresourcedir(self):
+        """Returns the RW resource directory if set in site-config"""
+        if self._rwresourcedir is None:
+            self._rwresourcedir = self._cI.get("RW_RESOURCE_PATH")
+        return self._rwresourcedir
+
     def _getreferencedir(self):
         if self._referencedir is None:
             self._referencedir = self._cI.get("REFERENCE_PATH")
@@ -119,6 +126,16 @@ class ConfigInfoAppCommon(ConfigInfoAppBase):
         newpath = os.path.join(self.get_mmcif_dict_path(), mmcif_dictionary_file_name)
         return self._getlegacy("SITE_MMCIF_DICT_FILE_PATH", newpath)
 
+    def get_mmcif_next_dictionary_sdb_file_path(self):
+        mmcif_dictionary_name = self.get_mmcif_deposit_dict_filename()
+        mmcif_dictionary_file_name = mmcif_dictionary_name + ".sdb"
+        return os.path.join(self.get_mmcif_dict_path(), mmcif_dictionary_file_name)
+
+    def get_mmcif_next_dictionary_odb_file_path(self):
+        mmcif_dictionary_name = self.get_mmcif_deposit_dict_filename()
+        mmcif_dictionary_file_name = mmcif_dictionary_name + ".odb"
+        return os.path.join(self.get_mmcif_dict_path(), mmcif_dictionary_file_name)
+
     def get_mmcif_archive_dictionary_file_path(self):
         mmcif_dictionary_name = self.get_mmcif_archive_current_dict_filename()
         mmcif_dictionary_file_name = mmcif_dictionary_name + ".dic"
@@ -150,7 +167,7 @@ class ConfigInfoAppCommon(ConfigInfoAppBase):
         return self._getlegacy("SF_VALID", os.path.join(self.get_site_packages_path(), "sf-valid"))
 
     def get_site_cc_inchi_dir(self):
-        return self._getlegacy("SITE_CC_INCHI_DIR", os.path.join(self.get_site_packages_path(), "bin"))
+        return self._getlegacy("SITE_CC_INCHI_DIR", os.path.join(self._get_site_local_apps(), "bin"))
 
     def get_site_cc_corina_dir(self):
         return self._getlegacy("SITE_CC_CORINA_DIR", os.path.join(self.get_site_packages_path(), "corina"))
@@ -168,7 +185,7 @@ class ConfigInfoAppCommon(ConfigInfoAppBase):
         return self._getlegacy("SITE_CC_BABEL_DIR", os.path.join(self.get_site_openbabel_dir(), "lib"))
 
     def get_site_cc_babel_datadir(self):
-        return self._getlegacy("SITE_CC_BABEL_DATADIR", os.path.join(self.get_site_openbabel_dir(), "share", "openbabel" "2.2.3"))
+        return self._getlegacy("SITE_CC_BABEL_DATADIR", os.path.join(self.get_site_openbabel_dir(), "share", "openbabel", "2.2.3"))
 
     def get_site_cc_acd_dir(self):
         return self._getlegacy("site_cc_acd_dir", os.path.join(self.get_site_packages_path(), "acd"))
@@ -255,36 +272,36 @@ class ConfigInfoAppCommon(ConfigInfoAppBase):
         reference_path = self._getreferencedir()
         return os.path.join(reference_path, "citation_finder")
 
-    def get_site_cc_dict_path(self):
+    def get_site_cc_dict_path(self, stacklevel=4):
         site_cc_dict_path = os.path.join(self.get_site_refdata_top_cvs_sb_path(), "cc-dict")
-        return self._getlegacy("SITE_CC_DICT_PATH", site_cc_dict_path)
+        return self._getlegacy("SITE_CC_DICT_PATH", site_cc_dict_path, stacklevel=stacklevel)
 
     def get_cc_dict(self):
-        return os.path.join(self.get_site_cc_dict_path(), "Components-all-v3.cif")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "Components-all-v3.cif")
 
     def get_cc_path_list(self):
-        return os.path.join(self.get_site_cc_dict_path(), "PATHLIST-v3")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "PATHLIST-v3")
 
     def get_cc_id_list(self):
-        return os.path.join(self.get_site_cc_dict_path(), "IDLIST-v3")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "IDLIST-v3")
 
     def get_cc_dict_serial(self):
-        return os.path.join(self.get_site_cc_dict_path(), "Components-all-v3.sdb")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "Components-all-v3.sdb")
 
     def get_cc_dict_idx(self):
-        return os.path.join(self.get_site_cc_dict_path(), "Components-all-v3-r4.idx")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "Components-all-v3-r4.idx")
 
     def get_cc_db(self):
-        return os.path.join(self.get_site_cc_dict_path(), "chemcomp_v3.db")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "chemcomp_v3.db")
 
     def get_cc_index(self):
-        return os.path.join(self.get_site_cc_dict_path(), "chemcomp-index.pic")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "chemcomp-index.pic")
 
     def get_cc_parent_index(self):
-        return os.path.join(self.get_site_cc_dict_path(), "chemcomp-parent-index.pic")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "chemcomp-parent-index.pic")
 
     def get_cc_fp_patterns(self):
-        return os.path.join(self.get_site_cc_dict_path(), "fp_patterns.txt")
+        return os.path.join(self.get_site_cc_dict_path(stacklevel=5), "fp_patterns.txt")
 
     def get_site_prdcc_cvs_path(self):
         site_prdcc_cvs_path = os.path.join(self.get_site_refdata_top_cvs_sb_path(), self._getValue("SITE_REFDATA_PROJ_NAME_PRDCC"))
@@ -378,6 +395,14 @@ class ConfigInfoAppDepUI(ConfigInfoAppBase):
         """Returns the preferred path to depui subdir of resources_ro"""
         return os.path.join(self._getresourcedir(), "depui")
 
+    def __get_rwdepui_dir(self):
+        """Returns the preferred path to depui subdir of resources_rw if variable set or None"""
+        rwpath = self._getrwresourcedir()
+        if rwpath is not None:
+            return os.path.join(rwpath, "depui")
+        else:
+            return None
+
     def get_depui_resources_ro_dir(self):
         """Performs legacy lookup of depUI subdir referenced through DEPUI_RESOURCE_PATH.
         Returns either legacy or new hardcoded lookup"""
@@ -388,7 +413,27 @@ class ConfigInfoAppDepUI(ConfigInfoAppBase):
         return self._getlegacy("SITE_ACCESS_INFO_FILE_PATH", newpath)
 
     def get_site_dataset_siteloc_file_path(self):
-        newpath = os.path.join(self.__get_depui_dir(), "site_dataset_siteloc_info.json")
+        """
+        Returhs in the following order:
+        site-config variable
+        r/w tree path
+        r/o resources path
+        """
+        fName = "site_dataset_siteloc_info.json"
+        rwdepuipath = self.__get_rwdepui_dir()
+
+        newpath = None
+
+        # Test if rw file exists. else old
+        if rwdepuipath is not None:
+            fpath = os.path.join(rwdepuipath, fName)
+            if os.path.exists(fpath):
+                newpath = fpath
+
+        if newpath is None:
+            newpath = os.path.join(self.__get_depui_dir(), fName)
+
+        # Legacy definition override
         return self._getlegacy("SITE_DATASET_SITELOC_FILE_PATH", newpath)
 
 
